@@ -163,7 +163,7 @@ class DNS_record(ClassParams):  # pylint: disable=C0103
                 ipaddress.IPv4Address(avalues[0])
             except ipaddress.AddressValueError as err:
                 raise SDSDNSError(message="record A requires"
-                                  " an IP address") from err
+                                  " an IPv4 address") from err
 
             self.values = {
                 '1': avalues[0]
@@ -174,8 +174,8 @@ class DNS_record(ClassParams):  # pylint: disable=C0103
             try:
                 ipaddress.IPv6Address(avalues[0])
             except ipaddress.AddressValueError as err:
-                raise SDSDNSError(message="record A "
-                                  "requires an IP address") from err
+                raise SDSDNSError(message="record AAAA "
+                                  "requires an IPv6 address") from err
 
             self.values = {
                 '1': avalues[0]
