@@ -13,6 +13,7 @@ SOLIDserver network manager
 # pylint: disable=too-many-branches
 
 import math
+import logging
 
 from packaging.version import Version, parse
 from SOLIDserverRest.Exception import (SDSEmptyError, SDSError,
@@ -252,11 +253,24 @@ class Network(ClassParams):
 
         anets = []
         for net in rjson:
-            anets.append({
+            if int(net['subnet_size']) == 0:
+                continue
+
+            _r = {
                 'start_hostaddr': net['start_hostaddr'],
                 'subnet_size': 32 - int(math.log(int(net['subnet_size']), 2)),
-                'subnet_name': net['subnet_name']
-            })
+                'subnet_name': net['subnet_name'],
+                'id': net['subnet_id'],
+                'terminal': net['is_terminal'] == '1',
+                'class': net['subnet_class_name'],
+                'level': net['subnet_level'],
+                'start_hex_ip': net['start_ip_addr'],
+            }
+
+            if net['is_terminal'] == '1':
+                _r['used_ip_percent'] = net['subnet_ip_used_percent']
+
+            anets.append(_r)
 
         # no limit, we should get all the records
         if len(rjson) == page:
@@ -444,13 +458,16 @@ class Network(ClassParams):
         if self.sds is None:
             raise SDSNetworkError(message="not connected")
 
-        try:
-            subnet_id = self._get_id(query="ip_subnet_list",
-                                     key="subnet")
-        except SDSError as err_descr:
-            msg = "cannot get network id"
-            msg += " / " + str(err_descr)
-            raise SDSNetworkError(msg) from err_descr
+        if self.myid <= 0:
+            try:
+                subnet_id = self._get_id(query="ip_subnet_list",
+                                         key="subnet")
+            except SDSError as err_descr:
+                msg = "cannot get network id"
+                msg += " / " + str(err_descr)
+                raise SDSNetworkError(msg) from err_descr
+        else:
+            subnet_id = self.myid
 
         params = {
             "subnet_id": subnet_id,
@@ -468,21 +485,22 @@ class Network(ClassParams):
         rjson = rjson[0]
         # logging.info(rjson)
 
-        labels = ['subnet_id',
-                  'subnet_name',
-                  'subnet_size',
-                  'subnet_level',
-                  'parent_subnet_id',
-                  'is_terminal',
-                  'subnet_allocated_size',
-                  'subnet_allocated_percent',
-                  'subnet_used_size',
-                  'subnet_used_percent',
-                  'subnet_ip_used_size',
-                  'subnet_ip_used_percent',
-                  'subnet_ip_free_size',
-                  'is_in_orphan',
-                  'tree_level']
+        labels = [
+            # 'subnet_id',
+            # 'subnet_name',
+            'subnet_size',
+            'subnet_level',
+            'parent_subnet_id',
+            # 'is_terminal',
+            'subnet_allocated_size',
+            'subnet_allocated_percent',
+            'subnet_used_size',
+            'subnet_used_percent',
+            'subnet_ip_used_size',
+            'subnet_ip_used_percent',
+            'subnet_ip_free_size',
+            'is_in_orphan',
+            'tree_level']
         if parse(self.sds.get_version()) >= Version("7.0.0"):
             labels.extend(['start_hostaddr', 'end_hostaddr'])
 
@@ -496,6 +514,9 @@ class Network(ClassParams):
             else:
                 self.is_block = False
 
+        if 'subnet_name' in rjson:
+            self.set_name(rjson['subnet_name'])
+
         if 'start_hostaddr' in rjson:
             self.subnet_addr = rjson['start_hostaddr']
 
